@@ -117,11 +117,24 @@ class AuthServerConnector:
         )
         return dict_to_dataclass(answer, JWTPayload)
 
-    async def refresh(self, refresh_token: str, origin: str) -> TokenPair:
+    async def refresh(
+        self,
+        refresh_token: str,
+        origin: str,
+        replace_refresh_token: bool = True,
+        server_name: str | None = None,
+    ) -> TokenPair:
+        headers = {hdrs.ORIGIN: origin}
+        if server_name is not None:
+            headers["server_name"] = server_name
+
         answer = await self._connector.post(
             path="/v1/refresh",
-            payload={"refresh_token": refresh_token},
-            headers={hdrs.ORIGIN: origin},
+            payload={
+                "refresh_token": refresh_token,
+                "replace_refresh_token": replace_refresh_token,
+            },
+            headers=headers,
         )
         return dict_to_dataclass(answer, TokenPair)
 
