@@ -38,7 +38,9 @@ class TokenValidator:
         self._public_key = None
         logger.info(f"{type(self).__name__} inited")
 
-    async def validate_access_token(self, token: str, origin: str) -> JWTPayload:
+    async def validate_access_token(
+        self, token: str, origin: str, *, enforce_same_domain: bool = True
+    ) -> JWTPayload:
         if token is None:
             raise InvalidTokenError("No access token")
 
@@ -57,7 +59,7 @@ class TokenValidator:
         if jwt_payload.type != TokenType.ACCESS_TOKEN:
             raise InvalidTokenError(f"Wrong token type, expected {TokenType.ACCESS_TOKEN}, got {jwt_payload.type}")
 
-        if jwt_payload.portal.origin != origin:
+        if enforce_same_domain and jwt_payload.portal.origin != origin:
             raise InvalidTokenError(f"Token doesn't belong to origin == {origin}")
 
         return jwt_payload
